@@ -1,11 +1,11 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
@@ -305,10 +305,7 @@ class TypeRegistry(BaseTypeRegistry):
             type_hint = self.get_type_hint(field.type)
 
             # build field definition
-            field_def = dict(
-                kw_only=True,
-                type=type_hint,
-            )
+            field_def = dict(kw_only=True, type=type_hint)
 
             # if building non-input type, all sub-fields are
             # optional as it's possible to request partial data
@@ -416,11 +413,7 @@ class TypeRegistry(BaseTypeRegistry):
         if docstring:
             cls.__doc__ = str(docstring)
 
-        self._register(
-            cls,
-            name=object_name,
-            submodule=self._get_submodule(namespace),
-        )
+        self._register(cls, name=object_name, submodule=self._get_submodule(namespace))
 
         return cls
 
@@ -444,11 +437,7 @@ class TypeRegistry(BaseTypeRegistry):
         if docstring:
             cls.__doc__ = str(docstring)
 
-        self._register(
-            cls,
-            name=object_name,
-            submodule=self._get_submodule(namespace),
-        )
+        self._register(cls, name=object_name, submodule=self._get_submodule(namespace))
 
         return cls
 
